//
//  TestVC-UIImagePickerControllerDelegate.m
//  Image2x
//
//  Created by boreal-kiss.com on 10/08/15.
//  Copyright 2010 boreal-kiss.com. All rights reserved.
//

#import "TestVC-UIImagePickerControllerDelegate.h"
#import "UIImage-Additions.h"
#import "UIImage-Image2x.h"

//Private
static const CGFloat ImageWidth		= 135.0;
static const CGFloat ImageHeight	= 135.0;

@interface TestVC ()
/**
 * Returns a squared image fit to the size of (ImageWidth, ImageHeight).
 */
-(UIImage *)_squaredImageWithImage:(UIImage *)image;

/**
 * Returns a squared image fit to the size of (2 x ImageWidth, 2 x ImageHeight).
 */
-(UIImage *)_squaredImage2xWithImage:(UIImage *)image;

/**
 * Returns the largest square within an image whose center is that of the image.
 */
-(CGRect)_croppingRectForImage:(UIImage *)image;
@end

@implementation TestVC (_UIImagePickerControllerDelegate)

- (void)imagePickerController:(UIImagePickerController *) picker didFinishPickingMediaWithInfo:(NSDictionary *) info{
	UIImage *originalImage = [info objectForKey:UIImagePickerControllerOriginalImage];
	
	//Creates cropped image objects for displaying purpose.
	UIImage *theImage	= [self _squaredImageWithImage:originalImage];
	UIImage *theImage2x = [self _squaredImage2xWithImage:originalImage];
		
	//Creates image data.
	NSData *imageData = UIImagePNGRepresentation(theImage);
	NSData *imageData2x = UIImagePNGRepresentation(theImage2x);
	
	//Reproduces image object from the data above.
	_imageView.image = [UIImage imageWithData:imageData];
	_imageView2x.image = [UIImage image2xWithData:imageData2x];
	
	[_imageView sizeToFit];
	[_imageView2x sizeToFit];
	
	[picker dismissModalViewControllerAnimated:YES];
}

- (void)imagePickerControllerDidCancel:(UIImagePickerController *) picker{
	[picker dismissModalViewControllerAnimated:YES];
}

#pragma mark -
#pragma mark Private

-(UIImage *)_squaredImageWithImage:(UIImage *)image{
	UIImage *rotatedImage = [UIImage rotatedImageWithImage:image];
	UIImage *croppedImage = [UIImage subimageWithImage:rotatedImage inRect:[self _croppingRectForImage:rotatedImage]];
	return [UIImage scaledImageWithImage:croppedImage inSize:CGSizeMake(ImageWidth, ImageHeight)];
}

-(UIImage *)_squaredImage2xWithImage:(UIImage *)image{
	UIImage *rotatedImage = [UIImage rotatedImageWithImage:image];
	UIImage *croppedImage = [UIImage subimageWithImage:rotatedImage inRect:[self _croppingRectForImage:rotatedImage]];
	return [UIImage scaledImageWithImage:croppedImage inSize:CGSizeMake(2.0 * ImageWidth, 2.0 * ImageHeight)];
}

-(CGRect)_croppingRectForImage:(UIImage *)image{
	CGFloat w = image.size.width;
	CGFloat h = image.size.height;
	
	if (w > h){
		return CGRectMake((w - h) / 2.0, 0, h, h);
	}
	
	return CGRectMake(0, (h - w) / 2.0, w, w);
}

@end
